% Parameters
c = 1; % speed of light (normalized)
theta = 1; % width of Gaussian pulse
t0 = 5 * theta; % delay of Gaussian pulse
xmax = 20; % spatial domain max
zeta_values = [1, 0.99, 0.5]; % stability factors
deltax = 1; % spatial resolution (grid spacing)
Nx = round(xmax / deltax); % number of spatial points

% Simulation parameters
timesteps = 1000; % total time steps
Nt = timesteps;

% Source initialization
source_position = 1; % index where source is injected

% Initialize fields
Ez = zeros(Nx, 1);
Hy = zeros(Nx, 1); % same size for simplicity, last element will not be used in the update

% Main FDTD loop
for zeta = zeta_values
    % Calculate time step based on zeta value
    deltat = zeta * deltax / c;

    % Reset fields for each run
    Ez(:) = 0;
    Hy(:) = 0;
    
    for T = 1:Nt
        % Update magnetic field Hy
        for nx = 1:Nx-1
            Hy(nx) = Hy(nx) + (deltat/deltax) * (Ez(nx+1) - Ez(nx));
        end

        % Update electric field Ez
        Ez(2:Nx-1) = Ez(2:Nx-1) + (deltat/deltax) * (Hy(2:Nx-1) - Hy(1:Nx-2));
        
        % Pulse source
        if T*deltat >= t0 - theta && T*deltat <= t0 + theta
            Ez(source_position) = Ez(source_position) + 1;
        end
        
        % Gaussian source
        Ez(source_position) = Ez(source_position) + ...
            (1/sqrt(2*pi*theta)) * exp(-(T*deltat - t0)^2 / (2*theta^2));
    end
    
    % Plot results
    figure;
    plot(Ez);
    title(['Ez field for zeta = ', num2str(zeta)]);
    xlabel('Grid Position');
    ylabel('Ez');
    drawnow;
end
